<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 yeni ismarıc</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Simsiz şəbəkəyə qoşulmaq istəyirsinizsə öncə &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Uçuş rejimi&lt;/a&gt;ni söndürün</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Şəbəkə</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>&quot;%1&quot; qoşulur</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; qoşuldu</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; ilə bağlantı kəsildi</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>&quot;%1&quot; ilə bağlantı mümkün deyil, lütfən routerinizi və ya şəbəkə kabelinizi yoxlayın.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>&quot;%1&quot; ilə bağlantı mümkün deyil, lütfən simsiz router cihazınıza yaxınlaşın.</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Bağlantı alınmadı, &quot;%1&quot; ilə bağlantı mümkün deyil, şifrə səhvdir</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>&quot;%1&quot; ilə bağlantı üçün şifrə tələb olunur</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>&quot;%1&quot; 802.11 WLAN şəbəkəsi tapılmadı</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>&quot;%1&quot; ilə bağlantı yaratmaq üçün, daxil olduqdan sonra kimlik doğrulaması məlumatlarınızı ayarlayın</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Məxfi şifrə</translation>
    </message>
    <message>
        <source>key</source>
        <translation>açar</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>Proksi şifrəsi</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>Qrup şifrəsi</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Ad (SSİD)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ləğv edin</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Qoşulun</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Simli bağlantını söndürün</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Simli bağlantını qoşun</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Simsiz bağlantını söndürün</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Simsiz bağlantını qoşun</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Şəbəkəni söndürün</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Şəbəkəni qoşun</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Şəbəkə ayarları</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected</source>
        <translation>Qoşuldu</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>Şəbəkəni söndürülüb</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Şəbəkə kabeli çıxarılıb</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlantı yoxdur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Qoşulur</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Qoşulub, lakin internetə giriş yoxdur</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Qoşulma alınmadı</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 qoşuldu</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Söndürülüb</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Simli şəbəkə</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Şəbəkə</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Simli şəbəkə</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli şəbəkəyə qoşulun</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Şəbəkələrim</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Başqa şəbəkələr</translation>
    </message>
</context>
</TS>